/*
 * This file is (c) Copyright Zarafa, The Netherlands, 2007
 *
 * Use of this file and the source contained within it is subject to the
 * license of the package it belongs to. See the LICENSE file in the
 * top-level directory of the package.
 *
 */

#ifndef MAPITOVMIME
#define MAPITOVMIME

#include <mapix.h>

#include <string>
#include <vmime/vmime.hpp>
#include <vmime/mailbox.hpp>
#include "mapidefs.h"
#include "ECLogger.h"
#include "options.h"

class MAPIToVMIME
{
public:
	MAPIToVMIME();
	MAPIToVMIME(IMAPISession *lpSession, ECLogger *newlogger, sending_options sopt);
	~MAPIToVMIME();

	HRESULT convertMAPIToVMIME(IMessage *lpMessage, vmime::message** lppVMMessage);

private:
	ECLogger *lpLogger;
	bool delete_logger;
	sending_options sopt;
	LPADRBOOK m_lpAdrBook;

	HRESULT handleTextparts(IMessage* lpMessage, vmime::messageBuilder* lpVMMessageBuilder, vmime::charset outgoingcharset, BOOL* lpbRealRTF);
	HRESULT fillVMIMEMail(IMessage *lpMessage, vmime::messageBuilder* lpVMMessageBuilder, vmime::charset outgoingcharset);
	HRESULT getMailBox(LPSRow lpRow, vmime::mailbox** lppVMMailbox, vmime::charset outgoingcharset);
	HRESULT processRecipients(IMessage* lpMessage, vmime::messageBuilder* lpVMMessageBuilder, vmime::charset outgoingcharset);
	HRESULT handleAttachments(IMessage* lpMessage, vmime::messageBuilder* lpVMMessageBuilder);
	HRESULT handleSingleAttachment(IMessage* lpMessage, LPSRow lpRow, vmime::messageBuilder* lpVMMessageBuilder);
	vmime::mediaType parseMimeTypeFromFilename(std::string strFilename);
	HRESULT setBoundaries(vmime::header *lpVMHeader, vmime::body *lpVMBody, std::string boundary);
	HRESULT handleXHeaders(IMessage* lpMessage, vmime::header *lpVMHeader);
	
	// build Messages
	HRESULT BuildNoteMessage(IMessage *lpMessage,  vmime::charset& charset, vmime::message **lppVMMessage);
	HRESULT BuildMDNMessage(IMessage *lpMessage, vmime::charset& charset, vmime::message **lppVMMessage);

	// util
	void capitalize(char *s);
	void removeEnters(char *s);
};

#endif
